@@ -24,31 +24,55 @@ Customised "sphinx_rtd_theme" used by my Python projects.
 #
 
 # stdlib
+import logging
 import os.path
 
 # 3rd party
+import sphinx.transforms
 import sphinx.writers.html5
 import sphinx_rtd_theme  # type: ignore
-from docutils import nodes
-from docutils.nodes import Element
+from docutils import nodes  # type: ignore
+from docutils.nodes import Element  # type: ignore
 from sphinx import addnodes
 from sphinx.application import Sphinx
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
-
 __license__: str = "MIT License"
-__version__: str = "0.4.0"
+__version__: str = "22.0.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __version_full__ = __version__
 
 __all__ = ["setup", "HTML5Translator"]
 
+logger = logging.getLogger(__name__)
+
+
+class FilterSystemMessages(sphinx.transforms.FilterSystemMessages):
+	"""
+	Filter system messages from a doctree.
+	"""
+
+	default_priority = 1024
+
+	def apply(self, **kwargs) -> None:
+		filterlevel = 2 if self.config.keep_warnings else 5
+		for node in self.document.traverse(nodes.system_message):
+			if node["level"] < filterlevel:
+				logger.debug("%s [filtered system message]", node.astext())
+				node.parent.remove(node)
+
+				if (
+						isinstance(node.parent, nodes.paragraph) and len(node.parent.children) == 1
+						and isinstance(node.parent.children[0], nodes.paragraph)
+						):
+					node.parent.children = node.parent.children[0].children
+
 
 class HTML5Translator(sphinx.writers.html5.HTML5Translator):
 	"""
-	Custom :class:`sphinx.writers.html5.HTML5Translator` to adjust spacing in bullet pointed lists.
+	Custom :class:`sphinx.writers.html5.HTML5Translator` to adjust spacing in bullet pointed lists, among other things.
 	"""
 
 	def visit_bullet_list(self, node: Element) -> None:  # noqa: D102
@@ -97,6 +121,12 @@ class HTML5Translator(sphinx.writers.html5.HTML5Translator):
 
 		self.body.append(self.starttag(node, "ol", **atts))
 
+	def visit_desc_name(self, node: addnodes.desc_name):  # noqa: D102
+		self.body.append(self.starttag(node, "code", '', CLASS="sig-name descname"))
+
+	def depart_desc_name(self, node: addnodes.desc_name):  # noqa: D102
+		self.body.append("</code>")
+
 
 def setup(app: Sphinx):
 	"""
@@ -113,6 +143,7 @@ def setup(app: Sphinx):
 		app.add_html_theme("domdf_sphinx_theme", theme_path)
 
 	app.set_translator("html", HTML5Translator, override=True)
+	app.add_transform(FilterSystemMessages)
 
 	return {
 			"version": __version__,
